@@ -1,4 +1,4 @@
-from Resources.resource import Resource
+from erp_sync.Resources.resource import Resource
 
 class ClientTypes(Resource):
 
