@@ -168,7 +168,9 @@ class Payments(Resource):
             # If client type is ZOHO
             elif super().get_client_type() == super().ZOHO:
 
-                payment = {}
+                payment = {
+                    "payment_mode": payload.get("payment_mode", "cash")
+                }
 
                 if 'customer_id' in payload.keys():
                     payment.update({
@@ -182,7 +184,7 @@ class Payments(Resource):
 
                 if 'reference' in payload.keys():
                     payment.update({
-                        "reference": payload.get("reference", "")
+                        "reference_number": payload.get("reference", "")
                     })
 
                 if 'description' in payload.keys():
